import setuptools

setuptools.setup(
    name="mocha-time",
    version="0.0.3",
    author="Jared Zhao",
    description="Python Performance Profiling for Production",
    url="https://github.com/mocha-dev/mocha",
    license="Apache 2.0",
    python_requires=">=3.6",
    packages=["mocha"],
)
